Demo of MochiKit.LoggingPane

# MochiKit.LoggingPane

Demonstrates MochiKit's MochiKit.Logging and MochiKit.LoggingPane.

Click one of the Logging Panes to pop up a view, and then start clicking on Logging Actions to see it in action!

Logging Panes:

- Debugging Bookmarklet - Pop-up with LoggingPane
- Inline LoggingPane

Logging Actions:

- logDebug(...)
- log(...)
- logWarning(...)
- logError(...)
- logFatal(...)

View Source:

- logging_pane.js
- index.html